@@ -22,7 +22,10 @@
 #define KSTREAMRIPPER_H
 
 #include <tdeversion.h>
+
 #include "kstreamripperbase.h"
+#include "processcontroller.h"
+
 #if KDE_IS_VERSION(3,3,90)
 #include <dnssd/servicebrowser.h>
 #include <dnssd/remoteservice.h>
@@ -33,12 +36,13 @@ namespace  DNSSD { namespace RemoteService { typedef int Ptr; } }
 #endif
 
 
-class AddNewStreamImpl;
+class TQPopupMenu;
+class StreamPropertiesDlg;
 class TQString;
 
 class KStreamRipper : public KStreamRipperBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -54,9 +58,12 @@ public:
 protected slots:
 
     void addStreamButtonClicked();
+    void editStreamButtonClicked();
     void deleteStreamButtonClicked();
+    void slotContextMenu( TQListViewItem*, const TQPoint &, int );
     void tuneInButtonClicked();
     void ripButtonClicked();
+    void ripStopped(ProcessController*);
     void stopRipButtonClicked();
     void browseButtonClicked();
     void helpButtonClicked();
@@ -64,10 +71,10 @@ protected slots:
     void quitButtonClicked();
 
     void selectedNewListItem();
-    void descriptionChanged();
-    void urlChanged();
 
-    void addStreamFinished( AddNewStreamImpl* );
+    void addStreamFinished( StreamPropertiesDlg* );
+    void editStreamFinished( StreamPropertiesDlg* );
+
 #if KDE_IS_VERSION(3,3,90)
     void serviceAdded(DNSSD::RemoteService::Ptr srv);
     void serviceRemoved(DNSSD::RemoteService::Ptr srv);
@@ -75,6 +82,9 @@ protected slots:
     void serviceAdded(DNSSD::RemoteService::Ptr) {};
     void serviceRemoved(DNSSD::RemoteService::Ptr) {};
 #endif
+private:
+
+    TQPopupMenu* contextMenu;
 };
 
 #endif
